@@ -1,7 +1,8 @@
 from __future__ import annotations
-from asyncio import AbstractEventLoop, TimerHandle
-import time
+
 import asyncio
+import time
+from asyncio import AbstractEventLoop, TimerHandle
 from typing import Union
 
 _MONOTONIC_RESOLUTION = time.get_clock_info("monotonic").resolution
@@ -10,7 +11,7 @@ ScheduledType = Union[TimerHandle, tuple[float, TimerHandle]]
 
 def get_scheduled_timer_handles(loop: AbstractEventLoop) -> list[TimerHandle]:
     """Return a list of scheduled TimerHandles."""
-    handles: list[ScheduledType] = loop._scheduled  # type: ignore[attr-defined] # noqa: SLF001
+    handles: list[ScheduledType] = loop._scheduled  # type: ignore[attr-defined]
     return [
         handle if isinstance(handle, TimerHandle) else handle[1] for handle in handles
     ]
