@@ -8,8 +8,6 @@ from aioresponses import aioresponses
 
 from yalexs.activity import (
     ACTION_BRIDGE_OFFLINE,
-    ACTION_LINKED_LOCK,
-    ACTION_LINKED_UNLOCK,
     ACTION_BRIDGE_ONLINE,
     ACTION_DOOR_CLOSE_2,
     ACTION_DOOR_CLOSED,
@@ -24,11 +22,15 @@ from yalexs.activity import (
     ACTION_HOMEKEY_LOCK,
     ACTION_HOMEKEY_UNLATCH,
     ACTION_HOMEKEY_UNLOCK,
+    ACTION_LINKED_LOCK,
+    ACTION_LINKED_UNLOCK,
     ACTION_LOCK_AUTO_LOCK,
     ACTION_LOCK_BLE_LOCK,
     ACTION_LOCK_BLE_UNLATCH,
     ACTION_LOCK_BLE_UNLOCK,
     ACTION_LOCK_DOORBELL_BUTTON_PUSHED,
+    ACTION_LOCK_FINGER_LOCK,
+    ACTION_LOCK_FINGER_UNLOCK,
     ACTION_LOCK_JAMMED,
     ACTION_LOCK_LOCK,
     ACTION_LOCK_LOCKING,
@@ -37,6 +39,7 @@ from yalexs.activity import (
     ACTION_LOCK_MANUAL_UNLOCK,
     ACTION_LOCK_ONETOUCHLOCK,
     ACTION_LOCK_ONETOUCHLOCK_2,
+    ACTION_LOCK_PIN_LOCK,
     ACTION_LOCK_PIN_UNLATCH,
     ACTION_LOCK_PIN_UNLOCK,
     ACTION_LOCK_REMOTE_LOCK,
@@ -137,6 +140,7 @@ class TestActivity(unittest.TestCase):
                 ACTION_LOCK_REMOTE_LOCK,
                 ACTION_LOCK_REMOTE_UNLATCH,
                 ACTION_LOCK_REMOTE_UNLOCK,
+                ACTION_LOCK_PIN_LOCK,
                 ACTION_LOCK_PIN_UNLATCH,
                 ACTION_LOCK_PIN_UNLOCK,
                 ACTION_LOCK_MANUAL_LOCK,
@@ -144,6 +148,8 @@ class TestActivity(unittest.TestCase):
                 ACTION_LOCK_MANUAL_UNLOCK,
                 ACTION_LINKED_LOCK,
                 ACTION_LINKED_UNLOCK,
+                ACTION_LOCK_FINGER_LOCK,
+                ACTION_LOCK_FINGER_UNLOCK,
             ],
         )
         self.assertCountEqual(
@@ -546,3 +552,57 @@ class TestActivityApiAsync(aiounittest.AsyncTestCase):
             manual_lock_activity.operator_thumbnail_url
             == "https://d3osa7xy9vsc0q.cloudfront.net/app/ActivityFeedIcons/linked_lock@3x.png"
         )
+
+    def test_finger_lock_activity(self):
+        keypad_lock_activity = LockOperationActivity(
+            SOURCE_LOG, json.loads(load_fixture("finger_lock_activity.json"))
+        )
+        assert keypad_lock_activity.operated_by == "Sample Person"
+        assert keypad_lock_activity.operated_remote is False
+        assert keypad_lock_activity.operated_keypad is True
+        assert keypad_lock_activity.operated_manual is False
+        assert keypad_lock_activity.operated_tag is False
+        assert (
+            keypad_lock_activity.operator_image_url
+            == "https://d33mytkkohwnk6.cloudfront.net/app/ActivityFeedIcons/finger_lock@3x.png"
+        )
+        assert (
+            keypad_lock_activity.operator_thumbnail_url
+            == "https://d33mytkkohwnk6.cloudfront.net/app/ActivityFeedIcons/finger_lock@3x.png"
+        )
+
+    def test_finger_unlock_activity(self):
+        keypad_lock_activity = LockOperationActivity(
+            SOURCE_LOG, json.loads(load_fixture("finger_unlock_activity.json"))
+        )
+        assert keypad_lock_activity.operated_by == "Sample Person"
+        assert keypad_lock_activity.operated_remote is False
+        assert keypad_lock_activity.operated_keypad is True
+        assert keypad_lock_activity.operated_manual is False
+        assert keypad_lock_activity.operated_tag is False
+        assert (
+            keypad_lock_activity.operator_image_url
+            == "https://d33mytkkohwnk6.cloudfront.net/app/ActivityFeedIcons/finger_unlock@3x.png"
+        )
+        assert (
+            keypad_lock_activity.operator_thumbnail_url
+            == "https://d33mytkkohwnk6.cloudfront.net/app/ActivityFeedIcons/finger_unlock@3x.png"
+        )
+
+    def test_pin_lock_activity(self):
+        keypad_lock_activity = LockOperationActivity(
+            SOURCE_LOG, json.loads(load_fixture("pin_lock_activity.json"))
+        )
+        assert keypad_lock_activity.operated_by == "Sample Person"
+        assert keypad_lock_activity.operated_remote is False
+        assert keypad_lock_activity.operated_keypad is True
+        assert keypad_lock_activity.operated_manual is False
+        assert keypad_lock_activity.operated_tag is False
+        assert (
+            keypad_lock_activity.operator_image_url
+            == "https://d33mytkkohwnk6.cloudfront.net/app/ActivityFeedIcons/pin_lock@3x.png"
+        )
+        assert (
+            keypad_lock_activity.operator_thumbnail_url
+            == "https://d33mytkkohwnk6.cloudfront.net/app/ActivityFeedIcons/pin_lock@3x.png"
+        )
