@@ -8,6 +8,7 @@ from abc import abstractmethod
 from collections.abc import Callable, Coroutine, Iterable, ValuesView
 from contextlib import suppress
 from datetime import datetime
+from enum import Enum
 from functools import partial
 from itertools import chain
 from typing import Any, ParamSpec, TypeVar
@@ -19,8 +20,8 @@ from ..activity import Activity, ActivityTypes, Source
 from ..backports.tasks import create_eager_task
 from ..const import Brand
 from ..doorbell import ContentTokenExpired, Doorbell, DoorbellDetail
-from ..exceptions import AugustApiAIOHTTPError
-from ..lock import Lock, LockDetail
+from ..exceptions import AugustApiAIOHTTPError, YaleApiError
+from ..lock import Lock, LockDetail, LockOperation
 from ..pubnub_activity import activities_from_pubnub_message
 from ..pubnub_async import AugustPubNub
 from .activity import ActivityStream
@@ -45,6 +46,13 @@ _R = TypeVar("_R")
 _P = ParamSpec("_P")
 
 
+class _PushUpdatesState(Enum):
+    """Push updates connection state."""
+
+    NOT_CONNECTED = "not_connected"
+    CONNECTED = "connected"
+
+
 def _save_live_attrs(lock_detail: DoorbellDetail | LockDetail) -> dict[str, Any]:
     """Store the attributes that the lock detail api may have an invalid cache for.
 
@@ -113,6 +121,11 @@ class YaleXSData(SubscriberMixin):
         # detail being None all over the place
         self._remove_inoperative_locks()
         self._remove_inoperative_doorbells()
+
+        # Fetch capabilities for locks (only for Yale brands)
+        if self.brand in (Brand.YALE_GLOBAL, Brand.YALE_HOME):
+            await self._async_fetch_lock_capabilities()
+
         await self.async_setup_activity_stream()
 
         if self._locks_by_id and self.brand is not Brand.YALE_GLOBAL:
@@ -145,6 +158,53 @@ class YaleXSData(SubscriberMixin):
         push.subscribe(push_callback)
         self._push_unsub = await push.run(user_data["UserID"], self.brand)
 
+    async def _async_fetch_lock_capabilities(self) -> None:
+        """Fetch capabilities for all locks from the API."""
+        token = await self._gateway.async_get_access_token()
+
+        # Fetch capabilities for each lock in series to keep API load low
+        for lock_id, lock_detail in self._device_detail_by_id.items():
+            if lock_id not in self._locks_by_id or not isinstance(
+                lock_detail, LockDetail
+            ):
+                continue
+
+            # lock_id is the serial_number for locks
+            try:
+                capabilities = await self._api.async_get_lock_capabilities(
+                    token, lock_id
+                )
+                lock_detail.set_capabilities(capabilities)
+                _LOGGER.debug(
+                    "Fetched capabilities for lock %s: unlatch=%s",
+                    lock_detail.device_name,
+                    capabilities.get("lock", {}).get("unlatch", False),
+                )
+            except YaleApiError as ex:
+                # 409 Conflict means the API cannot determine device type from serial
+                # 404 Not Found means device info not found
+                # These can happen for older devices, just log debug and continue
+                if ex.status in (404, 409):
+                    _LOGGER.debug(
+                        "Cannot fetch capabilities for lock %s (HTTP %s): %s",
+                        lock_detail.device_name,
+                        ex.status,
+                        str(ex),
+                    )
+                else:
+                    _LOGGER.warning(
+                        "Failed to fetch capabilities for lock %s (HTTP %s): %s",
+                        lock_detail.device_name,
+                        ex.status,
+                        str(ex),
+                    )
+            except (ClientError, TimeoutError) as ex:
+                _LOGGER.warning(
+                    "Failed to fetch capabilities for lock %s: %s",
+                    lock_detail.device_name,
+                    ex,
+                )
+
     async def _async_initial_sync(self) -> None:
         """Attempt to request an initial sync."""
         # We don't care if this fails because we only want to wake
@@ -463,6 +523,77 @@ class YaleXSData(SubscriberMixin):
             hyper_bridge,
         )
 
+    async def async_operate_lock(
+        self,
+        device_id: str,
+        operation: LockOperation,
+        push_updates_connected: bool = False,
+        hyper_bridge: bool = True,
+    ) -> list[ActivityTypes]:
+        """Unified method to operate the lock (lock/unlock/open).
+
+        Args:
+            device_id: The device ID
+            operation: The operation type (LockOperation enum)
+            push_updates_connected: If True, use async operation that doesn't wait for response
+            hyper_bridge: Whether to use hyper bridge for async operations
+
+        Returns:
+            Activities list when waiting for response, or empty list when using push updates
+
+        Note:
+            When unlatch is supported, unlock and open operations are swapped:
+            - UNLOCK operation calls unlatch API
+            - OPEN operation calls unlock API
+
+        """
+        # Base operation map - lock is always the same
+        operation_map = {
+            LockOperation.LOCK: {
+                _PushUpdatesState.NOT_CONNECTED: self.async_lock,
+                _PushUpdatesState.CONNECTED: self.async_lock_async,
+            },
+        }
+
+        # Check if the device supports unlatching to determine unlock/open mapping
+        detail = self.get_device_detail(device_id)
+        if detail and detail.unlatch_supported:
+            # When unlatch is supported, swap unlock and open operations
+            operation_map[LockOperation.UNLOCK] = {
+                _PushUpdatesState.NOT_CONNECTED: self.async_unlatch,  # Swapped!
+                _PushUpdatesState.CONNECTED: self.async_unlatch_async,
+            }
+            operation_map[LockOperation.OPEN] = {
+                _PushUpdatesState.NOT_CONNECTED: self.async_unlock,  # Swapped!
+                _PushUpdatesState.CONNECTED: self.async_unlock_async,
+            }
+        else:
+            # Normal mapping when unlatch is not supported
+            operation_map[LockOperation.UNLOCK] = {
+                _PushUpdatesState.NOT_CONNECTED: self.async_unlock,
+                _PushUpdatesState.CONNECTED: self.async_unlock_async,
+            }
+            operation_map[LockOperation.OPEN] = {
+                _PushUpdatesState.NOT_CONNECTED: self.async_unlatch,
+                _PushUpdatesState.CONNECTED: self.async_unlatch_async,
+            }
+
+        if operation not in operation_map:
+            raise ValueError(f"Invalid operation: {operation}")
+
+        # Determine the push updates state
+        state = (
+            _PushUpdatesState.CONNECTED
+            if push_updates_connected
+            else _PushUpdatesState.NOT_CONNECTED
+        )
+        method = operation_map[operation][state]
+
+        if push_updates_connected:
+            await method(device_id, hyper_bridge)
+            return []
+        return await method(device_id)
+
     async def _async_call_api_op_requires_bridge(
         self,
         device_id: str,
